@@ -3,41 +3,48 @@ import urllib
 from StringIO import StringIO
 import json
 import bson
+from wsgit.request import WebRequest
 
 
 class Environ(object):
 
-    def __init__(self, request_dict):
-        self.request_parameters = request_dict.get('parameters', {})
-        self.meta = request_dict.get('meta', {})
+    def __init__(self, request, meta):
+        if not isinstance(request, WebRequest):
+            raise TypeError('request must be an instance of WebRequest')
+
+        if not isinstance(meta, dict):
+            raise TypeError('meta must be an instance of dict')
+
+        self.request = request
+        self.meta = meta.copy()
 
     def get_dict(self):
-        if hasattr(self, 'environ'):
-            return self.environ
+        if hasattr(self, '_environ'):
+            return self._environ
         environ = dict()
-        for key in ('REQUEST_URI', 'PATH_INFO', 'QUERY_STRING', 'REMOTE_ADDR',
-                    'REMOTE_PORT', 'SERVER_NAME', 'SERVER_PORT', 'REQUEST_METHOD'):
+        for key in (
+            'REQUEST_URI', 'PATH_INFO', 'QUERY_STRING', 'REMOTE_ADDR',
+            'REMOTE_PORT', 'SERVER_NAME', 'SERVER_PORT', 'REQUEST_METHOD'
+        ):
             environ[key] = getattr(self, '_get_%s' % key.lower())()
         environ.update(self._get_wsgi_io_dict())
+        environ.update(self.request.headers)
         self.environ = environ
         return environ
 
     def _get_request_method(self):
-        if self.request_parameters:
-            return 'POST'
-        else:
-            return 'GET'
+        return self.request.request_method
 
     def _get_request_uri(self):
-        return self.request_parameters.get('url')
+        return self.request.url
 
     def _get_path_info(self):
-        url = self.request_parameters.get('url')
+        url = self.request.url
         if url is not None:
             return urlparse.urlparse(url).path
 
     def _get_query_string(self):
-        url = self.request_parameters.get('url')
+        url = self.request.url
         if url is not None:
             query = urlparse.urlparse(url).query
             return query
@@ -55,10 +62,7 @@ class Environ(object):
         return self.meta.get('server_port')
 
     def _get_wsgi_io_dict(self):
-        parameters = self.request_parameters.copy()
-        if 'url' in parameters:
-            del parameters['url']
-        post_body = urllib.urlencode(parameters)
+        post_body = urllib.urlencode(self.request.params)
         stream = StringIO()
         stream.write(post_body)
         stream.seek(0)
